coreapplicationuis/SysAp/Src/OfflineModeController/SysApOfflineModeControllerImpl.h
changeset 46 eea20ed08f4b
parent 0 2e3d3ce01487
child 63 c2c61fdca848
--- a/coreapplicationuis/SysAp/Src/OfflineModeController/SysApOfflineModeControllerImpl.h	Fri Jun 11 13:48:03 2010 +0300
+++ b/coreapplicationuis/SysAp/Src/OfflineModeController/SysApOfflineModeControllerImpl.h	Tue Jun 29 10:40:11 2010 +0300
@@ -1,19 +1,22 @@
 /*
 * Copyright (c) 2005 Nokia Corporation and/or its subsidiary(-ies). 
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
 * which accompanies this distribution, and is available
 * at the URL "http://www.eclipse.org/legal/epl-v10.html".
 *
 * Initial Contributors:
 * Nokia Corporation - initial contribution.
 *
 * Contributors:
 *
 * Description:  The stub implementation of MSysApOfflineModeController.
 *
 */
 
 
 #ifndef SYSAPOFFLINEMODECONTROLLERIMPL_H
@@ -27,6 +30,7 @@
 // FORWARD DECLARATIONS
 
 class CSysApAppUi;
+class CSysApCenRepOfflineModeObserver;
 
 // CLASS DECLARATION
 /**
@@ -160,6 +164,11 @@
 private:
 
     CSysApAppUi&        iSysApAppUi;
+	
+    /**
+    * Instance of the Offline mode observer. Listens to offline mode changes
+	*/	
+    CSysApCenRepOfflineModeObserver*         iSysApCenRepOfflineModeObserver;
 
     TBool               iOfflineModeActive;
     TBool               iDoNotActivateRF;
@@ -1,19 +1,22 @@
 /*
-* Copyright (c) 2005 Nokia Corporation and/or its subsidiary(-ies). 
-* All rights reserved.
-* This component and the accompanying materials are made available
-* under the terms of "Eclipse Public License v1.0"
-* which accompanies this distribution, and is available
-* at the URL "http://www.eclipse.org/legal/epl-v10.html".
-*
-* Initial Contributors:
-* Nokia Corporation - initial contribution.
-*
-* Contributors:
-*
-* Description:  The stub implementation of MSysApOfflineModeController.
-*
-*/
+ * Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies).
+ * All rights reserved.
+ * This component and the accompanying materials are made available
+ * under the terms of "Eclipse Public License v1.0"
+ * which accompanies this distribution, and is available
+ * at the URL "http://www.eclipse.org/legal/epl-v10.html".
+ *
+ * Initial Contributors:
+ * Nokia Corporation - initial contribution.
+ *
+ * Contributors:
+ *
+ * Description:
+ * CSysApOfflineModeController controls the offline mode.
+ * It turns OFF RF, BT and WLAN when offline mode is enabled and turns them ON when
+ * Offline mode is disabled
+ *
+ */
 
 